@@ -35,7 +35,7 @@ def get_appsettings_environments(csproj_directory_path: str, include_development
 
     logging.info(literals.get("dotnet_ef_utils_getting_appsettings_files").format(path=path))
 
-    files = path.glob(glob_pattern)
+    files = list(path.glob(glob_pattern))
     logging.info(literals.get("dotnet_ef_utils_appsettings_files_matched").format(files=files))
     for file in files:
         filename = os.path.basename(file)
@@ -77,3 +77,4 @@ def get_csproj_project_version(csproj_path: str) -> str:
 
 if __name__ == "__main__":
     help(__name__)
+    get_appsettings_environments(r"D:\Source\_aheadlabs\signatus\0.DistributedServicesLayer\SignatusApi")
